@@ -95,7 +95,8 @@ class RedshiftDataAPIServiceClient(BaseClient):
         DbUser: str = ...,
         SecretArn: str = ...,
         StatementName: str = ...,
-        WithEvent: bool = ...
+        WithEvent: bool = ...,
+        WorkgroupName: str = ...
     ) -> BatchExecuteStatementOutputTypeDef:
         """
         Runs one or more SQL statements, which can be data manipulation language (DML)
@@ -121,6 +122,14 @@ class RedshiftDataAPIServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client/#cancel_statement)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client/#close)
+        """
+
     def describe_statement(self, *, Id: str) -> DescribeStatementResponseTypeDef:
         """
         Describes the details about a specific instance when a query was run by the
@@ -141,7 +150,8 @@ class RedshiftDataAPIServiceClient(BaseClient):
         NextToken: str = ...,
         Schema: str = ...,
         SecretArn: str = ...,
-        Table: str = ...
+        Table: str = ...,
+        WorkgroupName: str = ...
     ) -> DescribeTableResponseTypeDef:
         """
         Describes the detailed information about a table from metadata in the cluster.
@@ -160,7 +170,8 @@ class RedshiftDataAPIServiceClient(BaseClient):
         Parameters: Sequence[SqlParameterTypeDef] = ...,
         SecretArn: str = ...,
         StatementName: str = ...,
-        WithEvent: bool = ...
+        WithEvent: bool = ...,
+        WorkgroupName: str = ...
     ) -> ExecuteStatementOutputTypeDef:
         """
         Runs an SQL statement, which can be data manipulation language (DML) or data
@@ -202,7 +213,8 @@ class RedshiftDataAPIServiceClient(BaseClient):
         DbUser: str = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        SecretArn: str = ...
+        SecretArn: str = ...,
+        WorkgroupName: str = ...
     ) -> ListDatabasesResponseTypeDef:
         """
         List the databases in a cluster.
@@ -221,7 +233,8 @@ class RedshiftDataAPIServiceClient(BaseClient):
         MaxResults: int = ...,
         NextToken: str = ...,
         SchemaPattern: str = ...,
-        SecretArn: str = ...
+        SecretArn: str = ...,
+        WorkgroupName: str = ...
     ) -> ListSchemasResponseTypeDef:
         """
         Lists the schemas in a database.
@@ -257,7 +270,8 @@ class RedshiftDataAPIServiceClient(BaseClient):
         NextToken: str = ...,
         SchemaPattern: str = ...,
         SecretArn: str = ...,
-        TablePattern: str = ...
+        TablePattern: str = ...,
+        WorkgroupName: str = ...
     ) -> ListTablesResponseTypeDef:
         """
         List the tables in a database.
